/*  This file is part of the KDE project
    Copyright (C) 2007-2008 Gökçen Eraslan <gokcen@pardus.org.tr>
    Copyright (C) 2008 Daniel Nicoletti <dantti85-pk@yahoo.com.br>
    Copyright (C) 2010 Dario Freddi <drf@kde.org>

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.

*/

#ifndef AUTHDIALOG_H
#define AUTHDIALOG_H

#include "ui_AuthDialog.h"
#include "ui_authdetails.h"

#include <PolkitTQt1/Identity>
#include <PolkitTQt1/ActionDescription>

namespace PolkitTQt1
{
class Details;
}

class AuthDialog : public KDialog, private Ui::AuthDialog
{
    Q_OBJECT
public:
    AuthDialog(const TQString &actionId,
               const TQString &message,
               const TQString &iconName,
               const PolkitTQt1::Details &details,
               const PolkitTQt1::Identity::List &identities,
               WId parent);
    ~AuthDialog();

    void setRequest(const TQString &request, bool requiresAdmin);
    void setOptions();
    TQString password() const;
    void authenticationFailure();

    PolkitTQt1::Identity adminUserSelected() const;

    PolkitTQt1::ActionDescription m_actionDescription;

signals:
    void adminUserSelected(PolkitTQt1::Identity);

public slots:
    virtual void accept();

private slots:
    void on_userCB_currentIndexChanged(int index);
    void notificationActivated(unsigned int action);

private:
    TQString m_appname;
    TQString m_message;

    void createUserCB(const PolkitTQt1::Identity::List &identities);
    void showEvent(TQShowEvent *);
};

class AuthDetails : public TQWidget, private Ui::AuthDetails
{
    Q_OBJECT
public:
    AuthDetails(const PolkitTQt1::Details &details,
                const PolkitTQt1::ActionDescription &actionDescription,
                const TQString &appname,
                TQWidget *parent);

private slots:
    void openUrl(const TQString&);
    void openAction(const TQString&);
};

#endif // AUTHDIALOG_H
