#ifndef POLICYKITLISTENER_H
#define POLICYKITLISTENER_H

/*  This file is part of the KDE project
    Copyright (C) 2009 Jaroslav Reznik <jreznik@redhat.com>

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.

*/

#include <PolkitTQt1/Agent/Listener>

#include <TQtCore/TQWeakPointer>
#include <TQtCore/TQHash>

class AuthDialog;

using namespace PolkitTQt1::Agent;

class PolicyKitListener : public Listener
{
    Q_OBJECT
    TQ_CLASSINFO("D-Bus Interface", "org.kde.Polkit1AuthAgent")
public:
    PolicyKitListener(TQObject *parent = 0);
    virtual ~PolicyKitListener();

public slots:
    void initiateAuthentication(const TQString &actionId,
                                const TQString &message,
                                const TQString &iconName,
                                const PolkitTQt1::Details &details,
                                const TQString &cookie,
                                const PolkitTQt1::Identity::List &identities,
                                PolkitTQt1::Agent::AsyncResult* result);
    bool initiateAuthenticationFinish();
    void cancelAuthentication();

    void tryAgain();
    void finishObtainPrivilege();

    void request(const TQString &request, bool echo);
    void completed(bool gainedAuthorization);
    void showError(const TQString &text);

    void setWIdForAction(const TQString &action, qulonglong wID);
    /*    void showInfo(const TQString &text);    */
private:
    TQWeakPointer<AuthDialog> m_dialog;
    TQWeakPointer<Session> m_session;
    bool m_inProgress;
    bool m_gainedAuthorization;
    bool m_wasCancelled;
    int m_numTries;
    PolkitTQt1::Identity::List m_identities;
    PolkitTQt1::Agent::AsyncResult* m_result;
    TQString m_cookie;
    PolkitTQt1::Identity m_selectedUser;
    TQHash< TQString, qulonglong > m_actionsToWID;

private slots:
    void dialogAccepted();
    void dialogCanceled();
    void userSelected(const PolkitTQt1::Identity &identity);
};

#endif
